Overview
--------

Chameleon compiles templates to Python byte-code. It includes a
complete implementation of the Zope Page Templates (ZPT) language.

The engine itself performs 10-15 times better than the reference
implementation and real-world benchmarks show an overall performance
improvement in complex applications of 30-50%.

Compatibility
-------------

Works on Python 2.4, 2.5 and 2.6, including Google App Engine.

Development
-----------

The code is maintained in a subversion repository::

  svn://svn.repoze.org/svn/chameleon/trunk

If you want to contribute or need support, join #repoze on freenode
irc or write the `mailinglist <mailto:repoze-dev@lists.repoze.org>`_.

